import logging
from decimal import Decimal

from rest_framework import viewsets

from suitablephones.models import Bluetooth, Camera, Device
from suitablephones.serializers import (BluetoothSerializer, CameraSerializer,
                                        DeviceSerializer)


# ViewSets define the view behavior.
class DeviceViewSet(viewsets.ModelViewSet):
    queryset = Device.objects.all()
    serializer_class = DeviceSerializer

    #http://url/api/devices?megapixel=3
    def get_queryset(self):
        megapixel = self.request.query_params.get('megapixel')
        if megapixel:
            self.queryset = self.queryset.filter(cameras__megapixel__lt=Decimal(megapixel))
        return self.queryset


    def get_cameras(self):
        return self.request.GET.getlist("cameras")


class BluetoothViewSet(viewsets.ModelViewSet):
    queryset = Bluetooth.objects.all()
    serializer_class = BluetoothSerializer


class CameraViewSet(viewsets.ModelViewSet):
    queryset = Camera.objects.all()
    serializer_class = CameraSerializer